package com.vendor.burn.model.devices.burners;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.burn.Messages;
import com.vendor.burn.commands.I2cCommand;
import com.vendor.burn.model.BurnContext;
import com.vendor.burn.model.ChipID;
import com.vendor.burn.model.FlashType;
import com.vendor.burn.model.TransferWay;
import com.vendor.burn.model.cmdline.BurnStatus;
import com.vendor.burn.model.define.IBurner;
import com.vendor.burn.model.define.IFastbootProgressMonitor;
import com.vendor.burn.model.devices.IBootBurner;
import com.vendor.burn.model.devices.IFrameSetting;
import com.vendor.burn.model.devices.ITab;
import com.vendor.burn.model.devices.burners.AbstractBurner;
import com.vendor.burn.model.monitor.CmdMonitor;
import com.vendor.burn.model.receive.ReceiveTimeOutException;
import com.vendor.burn.serial.workers.AbstractBurnerWorker;
import com.vendor.burn.serial.workers.FastbootBurnerWorker;
import com.vendor.burn.ui.burners.tabs.BootTab;
import com.vendor.burn.views.FastbootView;
import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.jobs.IJobChangeListener;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.osgi.util.NLS;

public class FastbootBurner extends AbstractBurner implements IBootBurner {
  private FlashType flashType;
  
  private String file;
  
  public FastbootBurner(BurnContext burnContext) {
    super(burnContext);
  }
  
  protected IFrameSetting getFrameSetting() {
    return getBurnContext().getDeviceSetting().getFrameSetting();
  }
  
  private boolean initTransferWay(IFastbootProgressMonitor fastbootMonitor, FastbootBurnerWorker worker) {
    if (fastbootMonitor != null)
      fastbootMonitor.begin(); 
    BurnContext context = getBurnContext();
    if (context.getTransferWay() == TransferWay.I2CBootrom)
      if (I2cCommand.I2cOpenChannelForBootrom(52, fastbootMonitor)) {
        FastbootBurnerWorker.infoln("\nI2C channels open success, the bit rate is " + I2cCommand.getBaudRate() + ", device address is 0x" + 
            Integer.toHexString(52));
      } else {
        FastbootBurnerWorker.infoln("I2C channels open failed");
        return false;
      }  
    return true;
  }
  
  public int burnCmdLine(IFastbootProgressMonitor fastbootMonitor) {
    FastbootBurnerWorker worker = (FastbootBurnerWorker)getBurnerWorker();
    worker.setProgressMonitor(fastbootMonitor);
    if (!initTransferWay(fastbootMonitor, worker))
      return BurnStatus.INIT_TRANSFER_WAY_FAILED.getErrorCode(); 
    boolean isUse = false;
    int errorCode = BurnStatus.SUCCESS.getErrorCode();
    CmdMonitor monitor = new CmdMonitor();
    try {
      isUse = worker.burn((IProgressMonitor)monitor, getFlashType(), getFile());
      if (!isUse) {
        closeByTrans();
        return BurnStatus.BURN_BOOT_FAILED.getErrorCode();
      } 
    } catch (IOException iOException) {
    
    } catch (ReceiveTimeOutException receiveTimeOutException) {
    
    } finally {
      if (!isUse && errorCode == BurnStatus.SUCCESS.getErrorCode())
        errorCode = BurnStatus.BURN_BOOT_FAILED.getErrorCode(); 
      if (fastbootMonitor != null) {
        fastbootMonitor.finish();
        closeByTrans();
      } 
    } 
    return errorCode;
  }
  
  public void burn(IFastbootProgressMonitor fastbootMonitor) {
    FastbootBurnerWorker worker = (FastbootBurnerWorker)getBurnerWorker();
    worker.setProgressMonitor(fastbootMonitor);
    if (!initTransferWay(fastbootMonitor, worker))
      return; 
    Object object = new Object(this, "Burn Fastboot", worker, fastbootMonitor);
    showProgressDialog((Job)object);
    object.addJobChangeListener((IJobChangeListener)new Object(this, fastbootMonitor));
    object.schedule();
  }
  
  public IStatus checkBeforeBurn() {
    IStatus validSerialPort = validSerialPort();
    if (!isOK(validSerialPort))
      return validSerialPort; 
    if (this.flashType == null)
      return error(Messages.AbstractBurner_msg_falshType_is_null); 
    if (this.file == null || this.file.trim().length() == 0)
      return error(Messages.AbstractBurner_msg_file_path_does_not_select); 
    File theFile = new File(this.file);
    if (!theFile.exists())
      return error(Messages.AbstractBurner_msg_the_file_does_not_exist); 
    if (theFile.isDirectory())
      return error(Messages.AbstractBurner_msg_the_file_can_not_be_a_directory); 
    if (0 == this.file.length())
      return error(
          NLS.bind(Messages.AbstractBurner_msg_the_file_size_must_be_nonzero, 
            Integer.valueOf(1))); 
    if (!FastbootView.isChipBranchSupportCheckFile() && 
      theFile.length() > 1048576L)
      return error(Messages.AbstractBurner_msg_the_bootFile_size_must_be_less_than_1m); 
    return null;
  }
  
  public String getFile() {
    return this.file;
  }
  
  public FlashType getFlashType() {
    return this.flashType;
  }
  
  public List<String> getSteps() {
    List<String> steps = new ArrayList<>();
    steps.add(Messages.FastbootBurner_Step_1);
    steps.add(Messages.FastbootBurner_Step_2);
    steps.add(Messages.FastbootBurner_Step_3);
    steps.add(Messages.FastbootBurner_Step_4);
    return steps;
  }
  
  public void setFile(String file) {
    this.file = file;
  }
  
  public void setFlashType(FlashType flashType) {
    this.flashType = flashType;
  }
  
  public ITab getTab() {
    return (ITab)new BootTab();
  }
  
  protected AbstractBurnerWorker getBurnerWorker() {
    return (AbstractBurnerWorker)new FastbootBurnerWorker(getFrameSetting(), (IBurner)this);
  }
  
  public ChipID getChipID() {
    return null;
  }
  
  public void setFlashId(ChipID chipId) {}
  
  public void burn(IFastbootProgressMonitor monitor, String directory) {}
}
